/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtChart.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtChart.h"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 87 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"

#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 127 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 460 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 130 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 471 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 133 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 136 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 139 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 142 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qarealegendmarker.sip"
#include <qarealegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qareaseries.sip"
#include <qareaseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarcategoryaxis.sip"
#include <qbarcategoryaxis.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarlegendmarker.sip"
#include <qbarlegendmarker.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarseries.sip"
#include <qbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qbarset.sip"
#include <qbarset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotlegendmarker.sip"
#include <qboxplotlegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxplotseries.sip"
#include <qboxplotseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qboxset.sip"
#include <qboxset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlesticklegendmarker.sip"
#include <qcandlesticklegendmarker.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickmodelmapper.sip"
#include <qcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickseries.sip"
#include <qcandlestickseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcandlestickset.sip"
#include <qcandlestickset.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qcategoryaxis.sip"
#include <qcategoryaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchart.sip"
#include <qchart.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qchartview.sip"
#include <qchartview.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qdatetimeaxis.sip"
#include <qdatetimeaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhbarmodelmapper.sip"
#include <qhbarmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhboxplotmodelmapper.sip"
#include <qhboxplotmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhcandlestickmodelmapper.sip"
#include <qhcandlestickmodelmapper.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalbarseries.sip"
#include <qhorizontalbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalpercentbarseries.sip"
#include <qhorizontalpercentbarseries.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhorizontalstackedbarseries.sip"
#include <qhorizontalstackedbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhpiemodelmapper.sip"
#include <qhpiemodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qhxymodelmapper.sip"
#include <qhxymodelmapper.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegend.sip"
#include <qlegend.h>
#line 28 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 34 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qlegendmarker.sip"
#include <qlegendmarker.h>
#line 205 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractaxis.sip"
#include <qabstractaxis.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractbarseries.sip"
#include <qabstractbarseries.h>
#line 26 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 32 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/sip/QtChart/qabstractseries.sip"
#include <qabstractseries.h>
#line 214 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 217 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 220 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpen.sip"
#include <qpen.h>
#line 223 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpainter.sip"
#include <qpainter.h>
#line 226 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 1031 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 229 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 232 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 235 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 164 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 238 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 224 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 241 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 244 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 384 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 247 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 438 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 250 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 253 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 98 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 256 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 259 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 262 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 103 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 265 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 268 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 271 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 164 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 274 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 277 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qaction.sip"
#include <qaction.h>
#line 280 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 283 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicswidget.sip"
#include <qgraphicswidget.h>
#line 286 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 289 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 292 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 115 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmargins.sip"
#include <qmargins.h>
#line 295 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpalette.sip"
#include <qpalette.h>
#line 298 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 301 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicslayout.sip"
#include <qgraphicslayout.h>
#line 304 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 307 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 312 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 315 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 318 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 321 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 324 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 327 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 330 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 333 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 336 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 339 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 342 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 345 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 348 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 351 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 354 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicstransform.sip"
#include <qgraphicstransform.h>
#line 357 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 360 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 607 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 363 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qtransform.sip"
#include <qtransform.h>
#line 366 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qregion.sip"
#include <qregion.h>
#line 369 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 372 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 375 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 119 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 378 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 88 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 381 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 363 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 384 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 509 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 387 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 199 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 390 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 139 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicssceneevent.sip"
#include <qgraphicssceneevent.h>
#line 393 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 329 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 396 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 399 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcursor.sip"
#include <qcursor.h>
#line 402 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 405 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 578 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsitem.sip"
#include <qgraphicsitem.h>
#line 408 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicsscene.sip"
#include <qgraphicsscene.h>
#line 411 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qgraphicslayoutitem.sip"
#include <qgraphicslayoutitem.h>
#line 414 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 417 "/build/python-pyqt5-chart/src/PyQtChart-5.15.7/build/QtChart/sipQtChartQtChartsQLegend.cpp"


PyDoc_STRVAR(doc_QtCharts_QLegend_paint, "paint(self, painter: QPainter|None, option: QStyleOptionGraphicsItem|None, widget: QWidget|None = None)");

extern "C" {static PyObject *meth_QtCharts_QLegend_paint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_paint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPainter* a0;
        const ::QStyleOptionGraphicsItem* a1;
        ::QWidget* a2 = 0;
        ::QtCharts::QLegend *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J8|J8", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QPainter, &a0, sipType_QStyleOptionGraphicsItem, &a1, sipType_QWidget, &a2))
        {
            (sipSelfWasArg ? sipCpp->::QtCharts::QLegend::paint(a0, a1, a2) : sipCpp->paint(a0, a1, a2));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_paint, doc_QtCharts_QLegend_paint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setBrush, "setBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setBrush, doc_QtCharts_QLegend_setBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_brush, "brush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QLegend_brush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_brush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->brush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_brush, doc_QtCharts_QLegend_brush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setPen, "setPen(self, pen: QPen|QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setPen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setPen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPen* a0;
        int a0State = 0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QPen, &a0, &a0State))
        {
            sipCpp->setPen(*a0);
            sipReleaseType(const_cast< ::QPen *>(a0), sipType_QPen, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setPen, doc_QtCharts_QLegend_setPen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_pen, "pen(self) -> QPen");

extern "C" {static PyObject *meth_QtCharts_QLegend_pen(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_pen(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QPen*sipRes;

            sipRes = new ::QPen(sipCpp->pen());

            return sipConvertFromNewType(sipRes, sipType_QPen, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_pen, doc_QtCharts_QLegend_pen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setAlignment, "setAlignment(self, alignment: Qt.Alignment|Qt.AlignmentFlag)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setAlignment(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Alignment* a0;
        int a0State = 0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_Qt_Alignment, &a0, &a0State))
        {
            sipCpp->setAlignment(*a0);
            sipReleaseType(a0, sipType_Qt_Alignment, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setAlignment, doc_QtCharts_QLegend_setAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_alignment, "alignment(self) -> Qt.Alignment");

extern "C" {static PyObject *meth_QtCharts_QLegend_alignment(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_alignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::Qt::Alignment*sipRes;

            sipRes = new ::Qt::Alignment(sipCpp->alignment());

            return sipConvertFromNewType(sipRes, sipType_Qt_Alignment, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_alignment, doc_QtCharts_QLegend_alignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_detachFromChart, "detachFromChart(self)");

extern "C" {static PyObject *meth_QtCharts_QLegend_detachFromChart(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_detachFromChart(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            sipCpp->detachFromChart();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_detachFromChart, doc_QtCharts_QLegend_detachFromChart);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_attachToChart, "attachToChart(self)");

extern "C" {static PyObject *meth_QtCharts_QLegend_attachToChart(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_attachToChart(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            sipCpp->attachToChart();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_attachToChart, doc_QtCharts_QLegend_attachToChart);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_isAttachedToChart, "isAttachedToChart(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QLegend_isAttachedToChart(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_isAttachedToChart(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAttachedToChart();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_isAttachedToChart, doc_QtCharts_QLegend_isAttachedToChart);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setBackgroundVisible, "setBackgroundVisible(self, visible: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setBackgroundVisible(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setBackgroundVisible(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QLegend *sipCpp;

        static const char *sipKwdList[] = {
            sipName_visible,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, &a0))
        {
            sipCpp->setBackgroundVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setBackgroundVisible, doc_QtCharts_QLegend_setBackgroundVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_isBackgroundVisible, "isBackgroundVisible(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QLegend_isBackgroundVisible(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_isBackgroundVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBackgroundVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_isBackgroundVisible, doc_QtCharts_QLegend_isBackgroundVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setColor, "setColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setColor, doc_QtCharts_QLegend_setColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_color, "color(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QLegend_color(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_color(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->color());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_color, doc_QtCharts_QLegend_color);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setBorderColor, "setBorderColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setBorderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setBorderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setBorderColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setBorderColor, doc_QtCharts_QLegend_setBorderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_borderColor, "borderColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QLegend_borderColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_borderColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->borderColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_borderColor, doc_QtCharts_QLegend_borderColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setFont, "setFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setFont(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setFont, doc_QtCharts_QLegend_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_font, "font(self) -> QFont");

extern "C" {static PyObject *meth_QtCharts_QLegend_font(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_font(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->font());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_font, doc_QtCharts_QLegend_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setLabelBrush, "setLabelBrush(self, brush: QBrush|QColor|Qt.GlobalColor|QGradient)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setLabelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setLabelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QBrush* a0;
        int a0State = 0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QBrush, &a0, &a0State))
        {
            sipCpp->setLabelBrush(*a0);
            sipReleaseType(const_cast< ::QBrush *>(a0), sipType_QBrush, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setLabelBrush, doc_QtCharts_QLegend_setLabelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_labelBrush, "labelBrush(self) -> QBrush");

extern "C" {static PyObject *meth_QtCharts_QLegend_labelBrush(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_labelBrush(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QBrush*sipRes;

            sipRes = new ::QBrush(sipCpp->labelBrush());

            return sipConvertFromNewType(sipRes, sipType_QBrush, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_labelBrush, doc_QtCharts_QLegend_labelBrush);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setLabelColor, "setLabelColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setLabelColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setLabelColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QColor* a0;
        int a0State = 0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLabelColor(*a0);
            sipReleaseType(a0, sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setLabelColor, doc_QtCharts_QLegend_setLabelColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_labelColor, "labelColor(self) -> QColor");

extern "C" {static PyObject *meth_QtCharts_QLegend_labelColor(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_labelColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->labelColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_labelColor, doc_QtCharts_QLegend_labelColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_markers, "markers(self, series: QAbstractSeries|None = None) -> list[QLegendMarker]");

extern "C" {static PyObject *meth_QtCharts_QLegend_markers(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_markers(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QAbstractSeries* a0 = 0;
        const ::QtCharts::QLegend *sipCpp;

        static const char *sipKwdList[] = {
            sipName_series,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J8", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QtCharts_QAbstractSeries, &a0))
        {
            QList< ::QtCharts::QLegendMarker*>*sipRes;

            sipRes = new QList< ::QtCharts::QLegendMarker*>(sipCpp->markers(a0));

            return sipConvertFromNewType(sipRes, sipType_QList_0101QtCharts_QLegendMarker, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_markers, doc_QtCharts_QLegend_markers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_hideEvent, "hideEvent(self, event: QHideEvent|None)");

extern "C" {static PyObject *meth_QtCharts_QLegend_hideEvent(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_hideEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QHideEvent* a0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QHideEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtCharts::QLegend::hideEvent(a0) : sipCpp->hideEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_hideEvent, doc_QtCharts_QLegend_hideEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_showEvent, "showEvent(self, event: QShowEvent|None)");

extern "C" {static PyObject *meth_QtCharts_QLegend_showEvent(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_showEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QShowEvent* a0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QShowEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtCharts::QLegend::showEvent(a0) : sipCpp->showEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_showEvent, doc_QtCharts_QLegend_showEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_reverseMarkers, "reverseMarkers(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QLegend_reverseMarkers(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_reverseMarkers(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->reverseMarkers();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_reverseMarkers, doc_QtCharts_QLegend_reverseMarkers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setReverseMarkers, "setReverseMarkers(self, reverseMarkers: bool = True)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setReverseMarkers(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setReverseMarkers(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;
        ::QtCharts::QLegend *sipCpp;

        static const char *sipKwdList[] = {
            sipName_reverseMarkers,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|b", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, &a0))
        {
            sipCpp->setReverseMarkers(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setReverseMarkers, doc_QtCharts_QLegend_setReverseMarkers);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_showToolTips, "showToolTips(self) -> bool");

extern "C" {static PyObject *meth_QtCharts_QLegend_showToolTips(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_showToolTips(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->showToolTips();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_showToolTips, doc_QtCharts_QLegend_showToolTips);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setShowToolTips, "setShowToolTips(self, show: bool)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setShowToolTips(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setShowToolTips(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, &a0))
        {
            sipCpp->setShowToolTips(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setShowToolTips, doc_QtCharts_QLegend_setShowToolTips);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_markerShape, "markerShape(self) -> QLegend.MarkerShape");

extern "C" {static PyObject *meth_QtCharts_QLegend_markerShape(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_markerShape(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtCharts_QLegend, &sipCpp))
        {
            ::QtCharts::QLegend::MarkerShape sipRes;

            sipRes = sipCpp->markerShape();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtCharts_QLegend_MarkerShape);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_markerShape, doc_QtCharts_QLegend_markerShape);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtCharts_QLegend_setMarkerShape, "setMarkerShape(self, shape: QLegend.MarkerShape)");

extern "C" {static PyObject *meth_QtCharts_QLegend_setMarkerShape(PyObject *, PyObject *);}
static PyObject *meth_QtCharts_QLegend_setMarkerShape(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtCharts::QLegend::MarkerShape a0;
        ::QtCharts::QLegend *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtCharts_QLegend, &sipCpp, sipType_QtCharts_QLegend_MarkerShape, &a0))
        {
            sipCpp->setMarkerShape(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLegend, sipName_setMarkerShape, doc_QtCharts_QLegend_setMarkerShape);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtCharts_QLegend(void *, const sipTypeDef *);}
static void *cast_QtCharts_QLegend(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtCharts::QLegend *sipCpp = reinterpret_cast< ::QtCharts::QLegend *>(sipCppV);

    if (targetType == sipType_QtCharts_QLegend)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QGraphicsWidget)->ctd_cast(static_cast< ::QGraphicsWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtCharts_QLegend(void *, int);}
static void release_QtCharts_QLegend(void *sipCppV, int)
{
    ::QtCharts::QLegend *sipCpp = reinterpret_cast< ::QtCharts::QLegend *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtCharts_QLegend(sipSimpleWrapper *);}
static void dealloc_QtCharts_QLegend(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtCharts_QLegend(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtCharts_QLegend[] = {{14, 2, 1}};


static PyMethodDef methods_QtCharts_QLegend[] = {
    {sipName_alignment, meth_QtCharts_QLegend_alignment, METH_VARARGS, doc_QtCharts_QLegend_alignment},
    {sipName_attachToChart, meth_QtCharts_QLegend_attachToChart, METH_VARARGS, doc_QtCharts_QLegend_attachToChart},
    {sipName_borderColor, meth_QtCharts_QLegend_borderColor, METH_VARARGS, doc_QtCharts_QLegend_borderColor},
    {sipName_brush, meth_QtCharts_QLegend_brush, METH_VARARGS, doc_QtCharts_QLegend_brush},
    {sipName_color, meth_QtCharts_QLegend_color, METH_VARARGS, doc_QtCharts_QLegend_color},
    {sipName_detachFromChart, meth_QtCharts_QLegend_detachFromChart, METH_VARARGS, doc_QtCharts_QLegend_detachFromChart},
    {sipName_font, meth_QtCharts_QLegend_font, METH_VARARGS, doc_QtCharts_QLegend_font},
    {sipName_hideEvent, meth_QtCharts_QLegend_hideEvent, METH_VARARGS, doc_QtCharts_QLegend_hideEvent},
    {sipName_isAttachedToChart, meth_QtCharts_QLegend_isAttachedToChart, METH_VARARGS, doc_QtCharts_QLegend_isAttachedToChart},
    {sipName_isBackgroundVisible, meth_QtCharts_QLegend_isBackgroundVisible, METH_VARARGS, doc_QtCharts_QLegend_isBackgroundVisible},
    {sipName_labelBrush, meth_QtCharts_QLegend_labelBrush, METH_VARARGS, doc_QtCharts_QLegend_labelBrush},
    {sipName_labelColor, meth_QtCharts_QLegend_labelColor, METH_VARARGS, doc_QtCharts_QLegend_labelColor},
    {sipName_markerShape, meth_QtCharts_QLegend_markerShape, METH_VARARGS, doc_QtCharts_QLegend_markerShape},
    {sipName_markers, SIP_MLMETH_CAST(meth_QtCharts_QLegend_markers), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QLegend_markers},
    {sipName_paint, SIP_MLMETH_CAST(meth_QtCharts_QLegend_paint), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QLegend_paint},
    {sipName_pen, meth_QtCharts_QLegend_pen, METH_VARARGS, doc_QtCharts_QLegend_pen},
    {sipName_reverseMarkers, meth_QtCharts_QLegend_reverseMarkers, METH_VARARGS, doc_QtCharts_QLegend_reverseMarkers},
    {sipName_setAlignment, meth_QtCharts_QLegend_setAlignment, METH_VARARGS, doc_QtCharts_QLegend_setAlignment},
    {sipName_setBackgroundVisible, SIP_MLMETH_CAST(meth_QtCharts_QLegend_setBackgroundVisible), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QLegend_setBackgroundVisible},
    {sipName_setBorderColor, meth_QtCharts_QLegend_setBorderColor, METH_VARARGS, doc_QtCharts_QLegend_setBorderColor},
    {sipName_setBrush, meth_QtCharts_QLegend_setBrush, METH_VARARGS, doc_QtCharts_QLegend_setBrush},
    {sipName_setColor, meth_QtCharts_QLegend_setColor, METH_VARARGS, doc_QtCharts_QLegend_setColor},
    {sipName_setFont, meth_QtCharts_QLegend_setFont, METH_VARARGS, doc_QtCharts_QLegend_setFont},
    {sipName_setLabelBrush, meth_QtCharts_QLegend_setLabelBrush, METH_VARARGS, doc_QtCharts_QLegend_setLabelBrush},
    {sipName_setLabelColor, meth_QtCharts_QLegend_setLabelColor, METH_VARARGS, doc_QtCharts_QLegend_setLabelColor},
    {sipName_setMarkerShape, meth_QtCharts_QLegend_setMarkerShape, METH_VARARGS, doc_QtCharts_QLegend_setMarkerShape},
    {sipName_setPen, meth_QtCharts_QLegend_setPen, METH_VARARGS, doc_QtCharts_QLegend_setPen},
    {sipName_setReverseMarkers, SIP_MLMETH_CAST(meth_QtCharts_QLegend_setReverseMarkers), METH_VARARGS|METH_KEYWORDS, doc_QtCharts_QLegend_setReverseMarkers},
    {sipName_setShowToolTips, meth_QtCharts_QLegend_setShowToolTips, METH_VARARGS, doc_QtCharts_QLegend_setShowToolTips},
    {sipName_showEvent, meth_QtCharts_QLegend_showEvent, METH_VARARGS, doc_QtCharts_QLegend_showEvent},
    {sipName_showToolTips, meth_QtCharts_QLegend_showToolTips, METH_VARARGS, doc_QtCharts_QLegend_showToolTips}
};

static sipEnumMemberDef enummembers_QtCharts_QLegend[] = {
    {sipName_MarkerShapeCircle, static_cast<int>(::QtCharts::QLegend::MarkerShapeCircle), 49},
    {sipName_MarkerShapeDefault, static_cast<int>(::QtCharts::QLegend::MarkerShapeDefault), 49},
    {sipName_MarkerShapeFromSeries, static_cast<int>(::QtCharts::QLegend::MarkerShapeFromSeries), 49},
    {sipName_MarkerShapeRectangle, static_cast<int>(::QtCharts::QLegend::MarkerShapeRectangle), 49},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtCharts_QLegend[] = {
    {"markerShapeChanged(MarkerShape)|(QtCharts::QLegend::MarkerShape)", "\1markerShapeChanged(self, shape: QLegend.MarkerShape)", SIP_NULLPTR, SIP_NULLPTR},
    {"showToolTipsChanged(bool)", "\1showToolTipsChanged(self, showToolTips: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"reverseMarkersChanged(bool)", "\1reverseMarkersChanged(self, reverseMarkers: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelColorChanged(QColor)", "\1labelColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"fontChanged(QFont)", "\1fontChanged(self, font: QFont)", SIP_NULLPTR, SIP_NULLPTR},
    {"borderColorChanged(QColor)", "\1borderColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorChanged(QColor)", "\1colorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"backgroundVisibleChanged(bool)", "\1backgroundVisibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtCharts_QLegend = {
    &::QtCharts::QLegend::staticMetaObject,
    0,
    signals_QtCharts_QLegend,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtChart_QtCharts_QLegend = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtCharts__QLegend,
        SIP_NULLPTR,
        &plugin_QtCharts_QLegend,
    },
    {
        sipNameNr_QLegend,
        {0, 0, 1},
        31, methods_QtCharts_QLegend,
        4, enummembers_QtCharts_QLegend,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtCharts_QLegend,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtCharts_QLegend,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtCharts_QLegend,
    cast_QtCharts_QLegend,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
